"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var path = require("path");
var serialize_error_1 = require("serialize-error");
var FILENAME = path.basename(__filename, path.extname(__filename));
exports.default = module.exports = (function (RED) {
    var DiscordInjectNode = function (config) {
        var _this = this;
        RED.nodes.createNode(this, config);
        var clientNode = RED.nodes.getNode(config.client);
        var key = RED.util.normalisePropertyExpression(config.key).join('.');
        var promises = config.to.map(RED.nodes.getNode)
            .map(function (node) { return new Promise(function (res, rej) {
            if (node === null)
                return;
            node.context().set(key, clientNode.getBot(), function (err) {
                if (err) {
                    var msg = {
                        _msgid: RED.util.generateId(),
                        targetNode: node.id,
                        payload: (0, serialize_error_1.serializeError)(err),
                    };
                    _this.status({
                        fill: 'red',
                        shape: 'dot',
                        text: 'failed to inject to ' + node.id,
                    });
                    _this.send(msg);
                }
                else {
                    node.on('close', function (done) {
                        node.context().set(config.key, undefined, config.store, done);
                    });
                }
                res(node);
            });
        }); });
        Promise.allSettled(promises).then(function () {
            _this.status({
                fill: 'green',
                shape: 'dot',
                text: 'injected'
            });
        });
    };
    RED.nodes.registerType(FILENAME, DiscordInjectNode);
});
