"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.asyncRED = exports.asyncContext = void 0;
function standardPromiseCallback(res, rej) {
    return function (err, val) {
        if (err) {
            rej(err);
        }
        else {
            res(val);
        }
    };
}
function asyncContext(context) {
    var get = function (key, store) { return new Promise(function (res, rej) {
        context.get(key, store, standardPromiseCallback(res, rej));
    }); };
    var set = function (key, value, store) { return new Promise(function (res, rej) {
        context.set(key, value, store, standardPromiseCallback(res, rej));
    }); };
    return { get: get, set: set };
}
exports.asyncContext = asyncContext;
function asyncRED(RED) {
    var util = RED.util;
    function evaluateNodePropertyAsync(node, prop, type, msg) {
        return new Promise(function (res, rej) {
            util.evaluateNodeProperty(prop, type, node, msg, standardPromiseCallback(res, rej));
        });
    }
    function evaluateJSONataExpressionAsync(node, expr, msg) {
        return new Promise(function (res, rej) {
            util.evaluateJSONataExpression(expr, msg, standardPromiseCallback(res, rej));
        });
    }
    function evaluatePropertyGetter(node, prop, type) {
        switch (type) {
            case 'msg':
                return function (msg) {
                    var paths = util.normalisePropertyExpression(prop).join('.');
                    return util.getMessageProperty(msg, paths);
                };
            case 'flow':
            case 'global':
            case 'env':
                return function (msg) { return evaluateNodePropertyAsync(node, prop, type, msg); };
            case 'bool':
                var bool_1 = /^true$/i.test(prop);
                return function () { return bool_1; };
            case 'num':
                var num_1 = Number(prop);
                return function () { return num_1; };
            case 'jsonata':
                var expr_1 = util.prepareJSONataExpression(prop, node);
                return function (msg) { return evaluateJSONataExpressionAsync(node, expr_1, msg); };
            case 'date':
                return function () { return new Date(); };
            case 'json':
                var obj_1 = JSON.parse(prop);
                return function () { return obj_1; };
            case 'bin':
                var bin_1 = Buffer.from(JSON.parse(prop));
                return function () { return bin_1; };
            default:
                return function () { return prop; };
        }
    }
    return {
        evaluateNodePropertyAsync: evaluateNodePropertyAsync,
        evaluateJSONataExpressionAsync: evaluateJSONataExpressionAsync,
        evaluatePropertyGetter: evaluatePropertyGetter
    };
}
exports.asyncRED = asyncRED;
